.. _changelog:

=========
Changelog
=========

Kallithea project doesn't keep its changelog here.  We refer you to our `Mercurial logs`__.


.. __: https://kallithea-scm.org/repos/kallithea/changelog
